"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const cloud_functions_1 = require("../cloud-functions");
const fixtures_1 = require("./fixtures");
describe('cloud functions', () => {
    it('should forward requests', async () => {
        const handler = jest.fn();
        const send = jest.fn();
        const payload = (0, fixtures_1.createPubSubRequest)('forward me');
        const fun = (0, cloud_functions_1.createPubSubCloudFunctions)(handler);
        await fun({ body: payload }, { status: () => ({ send }) });
        expect(handler).toHaveBeenCalled();
    });
    it('should run onError when thrown', async () => {
        const payload = (0, fixtures_1.createPubSubRequest)('forward me');
        const handle = () => {
            throw new Error('error');
        };
        const onError = jest.fn();
        const send = jest.fn();
        const fun = (0, cloud_functions_1.createPubSubCloudFunctions)(handle, {
            onError,
            context: () => ({ hello: 'world' }),
        });
        await fun({ body: payload }, { status: () => ({ send }) });
        expect(onError).toHaveBeenCalledWith(new Error('error'), {
            hello: 'world',
        });
    });
    it('should throw when onError is undefined', async () => {
        const payload = (0, fixtures_1.createPubSubRequest)('forward me');
        const handle = () => {
            throw new Error('error');
        };
        const send = jest.fn();
        const fun = (0, cloud_functions_1.createPubSubCloudFunctions)(handle);
        await fun({ body: payload }, { status: () => ({ send }) }).catch(e => expect(e.message).toBe('error'));
    });
    it('should return 200 by default', async () => {
        const payload = (0, fixtures_1.createPubSubRequest)('forward me');
        const handle = () => { };
        const send = jest.fn();
        const statusFun = jest.fn(() => ({ send }));
        const fun = (0, cloud_functions_1.createPubSubCloudFunctions)(handle);
        await fun({ body: payload }, { status: statusFun });
        expect(statusFun).toBeCalledTimes(1);
        expect(statusFun).toHaveBeenCalledWith(200);
    });
    it('should return status code of handler', async () => {
        const payload = (0, fixtures_1.createPubSubRequest)('forward me');
        const handle = () => ({ statusCode: 123 });
        const send = jest.fn();
        const statusFun = jest.fn(() => ({ send }));
        const fun = (0, cloud_functions_1.createPubSubCloudFunctions)(handle);
        await fun({ body: payload }, { status: statusFun });
        expect(statusFun).toBeCalledTimes(1);
        expect(statusFun).toHaveBeenCalledWith(123);
    });
});
//# sourceMappingURL=cloud-functions.test.js.map