"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const common_1 = require("../common");
const json_schema_faker_1 = require("json-schema-faker");
const types_1 = require("../types");
function createPubSubdata(input, stringify = true) {
    const message = json_schema_faker_1.JSONSchemaFaker.generate(types_1.pubSubMessageSchema);
    const data = Buffer.from(stringify ? JSON.stringify(input) : input).toString('base64');
    return {
        ...message,
        data,
    };
}
describe('common', () => {
    it('should handle simple PubSub messages', async () => {
        const message = createPubSubdata('hello-world', false);
        const handler = jest.fn();
        await (0, common_1.handlePubSubMessage)({
            message,
            handler,
            parseJson: false,
            context: {},
            log: {},
        });
        expect(handler).toHaveBeenCalledWith({
            message,
            data: 'hello-world',
            context: {},
            log: {},
        });
    });
    it('should handle JSON PubSub messages', async () => {
        const message = createPubSubdata({ name: 'Simen' });
        const handler = jest.fn();
        await (0, common_1.handlePubSubMessage)({
            message,
            handler,
            parseJson: true,
            context: {},
            log: {},
        });
        expect(handler).toHaveBeenCalledWith({
            message,
            data: { name: 'Simen' },
            context: {},
            log: {},
        });
    });
    it('should pass context', async () => {
        const message = createPubSubdata('');
        const handler = jest.fn();
        await (0, common_1.handlePubSubMessage)({
            message,
            handler,
            context: { hello: 'there' },
            log: {},
        });
        expect(handler).toHaveBeenCalledWith({
            message,
            data: '',
            context: { hello: 'there' },
            log: {},
        });
    });
    it('should run parser', async () => {
        const message = createPubSubdata({}, true);
        const handler = jest.fn();
        const parser = jest.fn(_ => '');
        await (0, common_1.handlePubSubMessage)({
            message,
            handler,
            parser: data => parser(data),
            context: {},
            log: {},
        });
        expect(handler).toHaveBeenCalledWith({
            message,
            data: '',
            context: {},
            log: {},
        });
        expect(parser).toHaveBeenCalledWith({});
    });
    it('should throw when parser fails', async () => {
        const message = createPubSubdata({}, true);
        const handler = jest.fn();
        const parser = jest.fn(_ => {
            throw new Error('error');
        });
        const result = () => {
            return (0, common_1.handlePubSubMessage)({
                message,
                handler,
                parser: data => parser(data),
                context: {},
                log: {},
            });
        };
        await expect(result).rejects.toThrowErrorMatchingInlineSnapshot(`"error"`);
    });
});
//# sourceMappingURL=common.test.js.map