"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createPubSubCloudFunctions = void 0;
const pino_1 = __importDefault(require("pino"));
const pino_cloud_logging_1 = require("pino-cloud-logging");
const common_1 = require("./common");
function createPubSubCloudFunctions(handler, options = {}) {
    const { parseJson, onError, logger } = options;
    return async (req, res) => {
        const context = options.context
            ? await options.context(req)
            : { req };
        try {
            const result = await (0, common_1.handlePubSubMessage)({
                message: req.body.message,
                handler,
                context,
                parseJson,
                log: (0, pino_1.default)((0, pino_cloud_logging_1.gcpLogOptions)(logger)),
            });
            res.status(result?.statusCode ?? 200).send();
        }
        catch (error) {
            if (onError) {
                await onError(error, context);
                res.status(200).send();
            }
            else {
                throw error;
            }
        }
    };
}
exports.createPubSubCloudFunctions = createPubSubCloudFunctions;
//# sourceMappingURL=cloud-functions.js.map