"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.pubSubFastifyPlugin = void 0;
const fastify_plugin_1 = __importDefault(require("fastify-plugin"));
const common_1 = require("./common");
const types_1 = require("./types");
const pubSubFastifyPluginFn = async (fastify, options) => {
    const fastifyTypeBox = fastify.withTypeProvider();
    const { path = '/', handler, parseJson, onError, parser } = options;
    fastifyTypeBox.post(path, {
        schema: {
            body: types_1.pubSubRequestSchema,
            response: { 204: {} },
        },
    }, async (req, reply) => {
        const context = options.context
            ? await options.context(req)
            : { req };
        try {
            const res = await (0, common_1.handlePubSubMessage)({
                parser,
                message: req.body.message,
                handler,
                parseJson,
                context,
                log: req.log,
            });
            return reply.code(res?.statusCode || 204).send();
        }
        catch (error) {
            if (onError) {
                await onError(error, context);
                return reply.code(204).send();
            }
            else {
                throw error;
            }
        }
    });
};
exports.pubSubFastifyPlugin = (0, fastify_plugin_1.default)(pubSubFastifyPluginFn, {
    name: 'pubsub-http-handler',
    fastify: '4.x',
});
//# sourceMappingURL=fastify-plugin.js.map