import { Static } from '@fastify/type-provider-typebox';
/**
 * PubSub Message Type
 *
 * This describes the message object that is sent to the handler
 * from Google PubSub.
 */
export declare const pubSubMessageSchema: import("@sinclair/typebox").TObject<{
    attributes: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TRecord<import("@sinclair/typebox").TString, import("@sinclair/typebox").TString>>;
    data: import("@sinclair/typebox").TString;
    messageId: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TString>;
}>;
export type PubSubMessage = Static<typeof pubSubMessageSchema>;
/**
 * PubSub Request Type
 *
 * This describes the request object that is sent to the handler
 * from Google PubSub.
 */
export declare const pubSubRequestSchema: import("@sinclair/typebox").TObject<{
    message: import("@sinclair/typebox").TObject<{
        attributes: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TRecord<import("@sinclair/typebox").TString, import("@sinclair/typebox").TString>>;
        data: import("@sinclair/typebox").TString;
        messageId: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TString>;
    }>;
    subscription: import("@sinclair/typebox").TString;
}>;
export type PubSubRequest = Static<typeof pubSubRequestSchema>;
export type OnErrorHandler<Context> = (error: unknown, context: Context) => void | Promise<void>;
export declare class PubSubHandlerResponse {
    statusCode?: number;
}
export type PubSubHandler<Data, Context, Logger> = (args: {
    message: PubSubMessage;
    data: Data;
    context: Context;
    log: Logger;
}) => Promise<PubSubHandlerResponse | void> | PubSubHandlerResponse | void;
export interface PubSubConfig<Data, Context> {
    /**
     * OnError Handler
     *
     * When this is set, errors will not be
     * thrown.
     */
    onError?: OnErrorHandler<Context>;
    parser?: (data: unknown) => Data | Promise<Data>;
    context?: () => Context | Promise<Context>;
    /**
     * This will run JSON.parse on request data
     *
     * **Tip**: `false` when sending strings
     * @default true
     */
    parseJson?: boolean;
    /**
     * Use this to set a different path
     * @default /
     */
    path?: string;
}
